@@ -37,6 +37,8 @@ class GuiApp(App, QWidget):
         QApplication.instance().setQuitOnLastWindowClosed(not config.ENABLE_TRAY)
         QApplication.instance().setApplicationName('FeelUOwn')
 
+        # Note that QApplication.setFont only works for those widgets that created
+        # after `QApplication.exec` (tested on macOS).
         if sys.platform == 'win32':
             font = QApplication.font()
             # By default, it uses SimSun(宋体) on windows, which is a little ugly.
@@ -56,6 +58,11 @@ class GuiApp(App, QWidget):
             # including windows, linux and macOS.
             font.setPixelSize(13)
             QApplication.setFont(font)
+        elif sys.platform == 'darwin':
+            font = QApplication.font()
+            # The default font can not show chinese in bold.
+            font.setFamilies(['arial', 'Hiragino Sans GB', 'sans-serif'])
+            QApplication.setFont(font)
 
         QWidget.__init__(self)
         App.__init__(self, *args, **kwargs)
