@@ -45,12 +45,12 @@ class MpvPlayer(AbstractPlayer):
             mpvkwargs['wid'] = winid
         self._version = _mpv_client_api_version()
 
-        # old version libmpv can use opengl-cb
-        if self._version < (1, 107):
-            mpvkwargs['vo'] = 'opengl-cb'
-            self.use_opengl_cb = True
-        else:
-            self.use_opengl_cb = False
+        # From libmpv 0.38, libmpv is not the default vo.
+        # Note if vo is not set to libmpv, the video is rendered in mpv's
+        # native window instead of feeluown's mpvwidget (tested on KDE+wayland).
+        # On macOS, this option is optional. I believe the option is also required
+        # on Windows.
+        mpvkwargs['vo'] = 'libmpv'
 
         # set log_handler if you want to debug
         # mpvkwargs['log_handler'] = self.__log_handler
